@@ -1,29 +1,22 @@
+import hashlib
+
 from django import template
 
-from ..helpers import get_content_id
+from ..helpers import deffered_get_content_id
 from ..settings import TORRENT_STREAM_PLAYER
-from ..exceptions import FailedResponse, ServerFault
 
 register = template.Library()
 
 
-def receive_content_id(torrent_file):
-    """content_id extractor
-    """
-    content = ""
-    if hasattr(torrent_file, 'read'):
-        content = torrent_file.read()
-    try:
-        return get_content_id(content)
-    except (FailedResponse, ServerFault):
-        return None
-
-
 def torrent_stream_player(torrent_file):
     """Common context for player/button templates
     """
+    if hasattr(torrent_file, 'read'):
+        content = torrent_file.read()
+        torrent_content_hash = hashlib.md5(content).hexdigest()
+        deffered_get_content_id(content, torrent_content_hash)
     return {
-        'content_id': receive_content_id(torrent_file),
+        'torrent_content_hash': torrent_content_hash,
         'TORRENT_STREAM_PLAYER': TORRENT_STREAM_PLAYER,
     }
 
